@@ -1,11 +1,13 @@
 package Acme::MetaSyntactic::Locale;
 use strict;
+use warnings;
 use Acme::MetaSyntactic (); # do not export metaname and friends
 use Acme::MetaSyntactic::MultiList;
 use List::Util qw( shuffle );
 use Carp;
 
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
+our $VERSION = '1.000';
 
 sub init {
     # alias the older package variable %Locale to %MultiList
